@@ -1,11 +1,10 @@
 package transport
 
 import (
+	"errors"
 	"net"
-
-	"github.com/pkg/errors"
 )
 
-func Dial(endpoint string) (net.Conn, string, error) {
+func Dial(_ string) (net.Conn, string, error) {
 	return nil, "", errors.New("unsupported")
 }
